
//---------------------------------------------------------------------------------------
//-------------------------------  BUTTON     -------------------------------------------
//---------------------------------------------------------------------------------------
volatile int8_t EncoderVal = 0; //This variable will increase or decrease depending on the rotation of encoder
uint8_t StatusSwitch = 0;       // state machine
uint8_t PressButton = 0;        // variable that is set to 1 in short press and to 2 in long
uint8_t TimePressed = 0;        // Counter of 10msec that the button is pressed

void leerswitch(void) {

  switch (StatusSwitch) {
    case 0:
      if (!digitalRead(PinMenu))StatusSwitch++;
      return;
    case 1:
    case 2:
    case 3:
      StatusSwitch++;
      TimePressed = 0;
      return;
    case 4:
      if (!digitalRead(PinMenu)) {
        TimePressed++;
        if (TimePressed >= 60) {
          PressButton = 2;
          StatusSwitch = 5;
        }
      }
      else {
        PressButton = 1;
        StatusSwitch = 0;
      }
      return;
    case 5:
      if (digitalRead(PinMenu))StatusSwitch = 0; // we return to initial state
      return;
  }
}

const char StepSizeStr[][12] = {
  "STEP    1Hz",
  "STEP   10Hz",
  "STEP  100Hz",
  "STEP   1kHz",
  "STEP  10kHz",
  "STEP 100kHz",
  "STEP   1MHz"
};

const uint32_t StepSize[] = {1L, 10L, 100L, 1000L, 10000L, 100000L, 1000000L};

/********************************************************************************************************
  Format with point in the thousands and dispense last number if necessary
  Ex ... 10,345.00 would be 10Mhz 345,000 hz
  receives as a parameter a pointer to a 32-bit number and the pointer where the string is returned
*********************************************************************************************************/
void PrintFreq(uint32_t * Fr, char *c) {
  char Herz[10]; // we reserve a string of 10 characters long
  int8_t p;

  Herz[0] = ' '; // blank spaces to fill in the unused figures on the left
  Herz[1] = ' ';
  Herz[2] = ' ';
  Herz[3] = ' ';
  Herz[5] = '.';

  // sprintf (c, "% ld", * Fr) ==> converts a number into a string. The array c is the destination string
  // "% ld" is the format of the conversion,% = control l = long d = decimal, * Fr points to the number to be converted.
  // sprintf (c, "the frequency is% ld herzios", * Fr); would put in the array c = "the frequency is 54789 Hz"

  sprintf(c, "%ld", *Fr);            // convert freq to string. http://es.cppreference.com/w/cpp/io/c/fprintf
  p = strlen(c);                     // determines string length
  switch (p) {
    case 5:
      strncpy(Herz + 3, c , 2);      //http://www.cplusplus.com/reference/cstring/strncpy/
      strncpy(Herz + 6, c + 2 , 3);  // pointer to destination Herz + 6, from the origin c + 2, 3 elements
      break;
    case 6:
      strncpy(Herz + 2, c , 3);
      strncpy(Herz + 6, c + 3 , 3);  // pointer to destination Herz + 6, from the origin c + 3, 3 elements
      break;
    case 7:
      Herz[0] = c[0];
      Herz[1] = ',';
      strncpy(Herz + 2, c + 1 , 3);
      strncpy(Herz + 6, c + 4 , 3);
      break;
    case 8:
      strncpy(Herz , c, 2);
      Herz[2] = ',';
      strncpy(Herz + 3, c + 2 , 3);
      Herz[6] = '.';
      strncpy(Herz + 7, c + 5 , 2);
  }
  Herz[9] = 0;        // all string has to end in 0
  strcpy(c, Herz);    // the formatted string in the pointer is copied. http://www.cplusplus.com/reference/cstring/strcpy/
}

/***********************************************************************************
  This routine paints the screen according to the menu
  It does not receive parameters since it uses the state of the main state machine
 * *********************************************************************************
*/
void PrintMenu (void) {
  char LCDstr[10];
  PrintFreq(&vfo_t, LCDstr);

  // sprintf(LCDstr, "f= %ld Hz bat= %d V", vfo_t, Vbat);
  // vfo_t = 103 bat = 13 ==> LCDstr would look like this "f = 103 Hz bat = 13 V"

  u8g2.firstPage();
  do {
    // Main screen ---------------------------
    u8g2.setFont(u8g2_font_logisoso22_tn);
    u8g2.drawStr(0, 24, LCDstr);

    u8g2.setFont(u8g2_font_6x13_t_hebrew);
    u8g2.drawStr(5, 40, StepSizeStr[steps]);

    // Lower status line ----------------------
    u8g2.drawHLine(0, 50, 128);
    u8g2.drawStr(20, 62, "www.ea3gcy.com");
  } while ( u8g2.nextPage() );
  return;
}

uint8_t IsButtonPressed() {
  uint8_t tmp;
  if (PressButton != 0) {
    tmp = PressButton;
    PressButton = 0;
    return tmp;
  }
  return 0;
}

//---------------------------------------------------------------------------------------
//-------------------------------  TIME BASE  ------------------------------------------
//---------------------------------------------------------------------------------------

unsigned long tiempoAhora10mseg = 0;
boolean Tiempo10mseg(void) {
  unsigned long tmp;
  tmp = micros();
  if ((tmp - tiempoAhora10mseg) >= 10000UL) {
    tiempoAhora10mseg = tmp;
    return 1;
  }
  return 0;
}

